// https://github.com/webpack/webpack/issues/8656#issuecomment-456001556

// import "core-js/es";

// import(/* webpackChunkName: "autocomplete" */ './components/autocomplete');
// import(/* webpackChunkName: "feedbacks" */ './components/feedbacks');

import Awesomplete from './vendor/awesomplete';
import Swiper from './vendor/swiper';

// const swiper = new Swiper('.c-feedbacks--inner', {
//     speed: 900,
//     autoplay: {
//         delay: 6000,
//         disableOnInteraction: false
//     },
//     grabCursor: true,
//     loop: true,
//     pagination: {
//         el: '.swiper-pagination',
//         clickable: true
//     }
// });

const swiper = new Swiper('.c-feedbacks--inner', {
    effect: 'coverflow',
    grabCursor: false,
    centeredSlides: true,
    slidesPerView: 'auto',
    slideToClickedSlide: true,
    coverflowEffect: {
        rotate: 0,
        stretch: 0,
        depth: 300,
        modifier: 1,
        slideShadows: false
    },
    speed: 900,
    autoplay: {
        delay: 6000,
        disableOnInteraction: false
    },
    // grabCursor: true,
    loop: true,
    // pagination: {
    //     el: '.swiper-pagination',
    //     clickable: true
    // }
});

// var swiper = new Swiper('.swiper-container', {
//   effect: 'coverflow',
//   grabCursor: true,
//   centeredSlides: true,
//   slidesPerView: 'auto',
//   coverflowEffect: {
//     rotate: 50,
//     stretch: 0,
//     depth: 100,
//     modifier: 1,
//     slideShadows : true,
//   },
//   pagination: {
//     el: '.swiper-pagination',
//   },
// });

const lisp = (str) => {
    var symbols = {
        'ą': 'a',
        'č': 'c',
        'ę': 'e',
        'ė': 'e',
        'į': 'i',
        'š': 's',
        'ų': 'u',
        'ū': 'u',
        'ž': 'z',

        'ā': 'a',
        'ē': 'e',
        'ģ': 'g',
        'ī': 'i',
        'ķ': 'k',
        'ļ': 'l',
        'ņ': 'n',

        'õ': 'o',
        'ä': 'a',
        'ö': 'o',
        'ü': 'u'
    };

    str = str.trim();

    str = str.toLowerCase();

    str = str.replace(/[ąčęėįšųūžāēģīķļņõäöü]/g, (s) => {
        return symbols[s];
    });

    return str;
};

const autocomplete = (str) => {
    const node = document.getElementById(str);
    const arrow = document.querySelector('.js-toggle--' + str);
    const clear = document.querySelector('.js-clear--' + str);

    let isOpen = false;

    const update = (langID, target, str, hidden) => {
        const type = (target.id === 'search-city') ? 'query' : 'city';

        fetch('/wp-json/api/v1/options?langID=' + langID + '&str=' + str + '&type=' + type)
            .then((t) => t.json())
            .then((data) => {
                if (!data || !data.length) {
                    return;
                }

                const list = data.map((option) => {
                    return { label: option.name + ' (' + option.total + ')', value: option.name };
                });

                target.box.list = list;
                if (hidden) {
                    target.box.evaluate();
                    target.box.close();
                } else {
                    target.focus();
                    target.box.evaluate();
                }
            });
    };

    const updateOptions = (node) => {
        const target = (node.id === 'search-city') ? document.getElementById('search-query') : document.getElementById('search-city');

        if (!target || (target.value && node.value)) {
            return;
        }

        if (!target.value && node.value) {
            update(node.dataset.id, target, node.value, true);
        } else if (!node.value) {
            update(node.dataset.id, node, target.value);

            if (!target.value) {
                update(node.dataset.id, target, target.value, true);
            }
        }
    };

    const toggle = (status, delay = 0) => {
        setTimeout(() => {
            isOpen = status;
        }, delay);

        if (arrow) {
            arrow.classList.toggle('is-open', status);
        }
    };

    if (!node) {
        return;
    }

    const box = new Awesomplete(node, {
        minChars: 0,
        maxItems: 1000,
        sort: false,
        filter: function (text, input) {
            return lisp(text).indexOf(lisp(input)) !== -1;
        }
    });

    node.addEventListener('input', () => {
        if (clear) {
            clear.classList.toggle('u-hidden', !node.value);
        }
        if (arrow) {
            arrow.classList.toggle('u-hidden', !!node.value);
        }
    });

    node.addEventListener('focus', () => {
        if (box.ul.childNodes.length === 0 || box.ul.hasAttribute('hidden')) {
            toggle(true);
            box.evaluate();
        } else {
            toggle(false);
            box.close();
        }
    });

    node.addEventListener('blur', () => {
        const suggestion = (Array.isArray(box.suggestions) && box.suggestions.length === 1) ? box.suggestions[0] : null;

        if (!suggestion) {
            return;
        }

        if (lisp(node.value) === lisp(suggestion.value)) {
            node.value = suggestion.value;
        }
    });

    node.addEventListener('awesomplete-selectcomplete', () => {
        node.blur();

        updateOptions(node);

        if (clear) {
            clear.classList.remove('u-hidden');
        }
        if (arrow) {
            arrow.classList.add('u-hidden');
        }
    });

    node.addEventListener('awesomplete-close', () => {
        toggle(false, 150);
    });

    if (arrow) {
        arrow.addEventListener('click', () => {
            if (!isOpen) {
                node.focus();
            } else {
                box.close();
            }
        });
    }

    if (clear) {
        clear.addEventListener('click', () => {
            node.value = '';

            updateOptions(node);

            if (clear) {
                clear.classList.add('u-hidden');
            }
            if (arrow) {
                arrow.classList.remove('u-hidden');
            }
        });
    }

    node.box = box;
};

autocomplete('search-city');
autocomplete('search-query');

const search = document.getElementById('search');
const city = document.getElementById('search-city');
const query = document.getElementById('search-query');

if (search) {
    search.addEventListener('submit', (e) => {
        if (city && !city.value && query && !query.value) {
            city.focus();
            e.preventDefault();
        }
    }, false);
}

const setCityAwesomplete = (node, cityID) => {

    if (!node || !cityID) {
        return;
    }

    const nodeBox = new Awesomplete(node, {
        minChars: 0,
        maxItems: 1000,
        sort: false,
        filter: function (text, input) {
            return lisp(text).indexOf(lisp(input)) !== -1;
        },
        replace: function (suggestion) {
            this.input.value = suggestion.label;

            if (cityID) {
                cityID.value = suggestion.value;
            }
        }
    });

    node.addEventListener('focus', () => {
        nodeBox.evaluate();
    });

    node.addEventListener('blur', () => {
        const suggestion = (Array.isArray(nodeBox.suggestions) && nodeBox.suggestions.length === 1) ? nodeBox.suggestions[0] : null;

        if (!suggestion) {
            return;
        }

        if (lisp(node.value) === lisp(suggestion.label)) {
            node.value = suggestion.label;

            if (cityID) {
                cityID.value = suggestion.value;
            }
        }
    });
};

setCityAwesomplete(document.getElementById('form-city'), document.getElementById('form-city-id'));
setCityAwesomplete(document.getElementById('recommend-form-city'), document.getElementById('recommend-form-city-id'));

if (window.NodeList && !NodeList.prototype.forEach) {
    NodeList.prototype.forEach = Array.prototype.forEach;
}

(function (arr) {
    arr.forEach(function (item) {
        if (item.hasOwnProperty('remove')) {
            return;
        }
        Object.defineProperty(item, 'remove', {
            configurable: true,
            enumerable: true,
            writable: true,
            value: function remove () {
                if (this.parentNode === null) {
                    return;
                }
                this.parentNode.removeChild(this);
            }
        });
    });
})([Element.prototype, CharacterData.prototype, DocumentType.prototype]);

(global => {
    const container = document.getElementById('cookie-warning');
    const btnAgree = document.getElementById('cookie-agree');
    const btnClose = document.getElementById('cookie-close');
    const agreed = (useLS()) ? localStorage.getItem('biuro-agree') : false;

    function useLS () {
        var mod = 'a';
        try {
            localStorage.setItem(mod, mod);
            localStorage.removeItem(mod);
            return true;
        } catch (e) {
            return false;
        }
    }

    if (!container || !btnAgree || !btnClose || agreed) {
        return;
    }

    container.style.display = 'block';

    btnAgree.addEventListener('click', () => {
        if (useLS()) {
            localStorage.setItem('biuro-agree', 'true');
        }
        container.style.display = 'none';
    });

    btnClose.addEventListener('click', () => {
        container.style.display = 'none';
    });
})(window);

if (module.hot) {
    module.hot.accept();
}

(global => {
    const node = document.getElementById('js-map--divisions');

    if (!node) {
        return;
    }

    fetch('/wp-json/api/v1/divisions?langID=' + node.dataset.id)
        .then((t) => t.json())
        .then((data) => {
            initDivisionsMap(node, data);
        });
})(window);

(global => {
    const node = document.getElementById('js-map--cities');

    if (!node) {
        return;
    }

    fetch('/wp-content/themes/biuro/json/' + node.dataset.source + '.json')
        .then((t) => t.json())
        .then((data) => {
            // initDivisionsMap(node, data);
            initCitiesMap(node, data);
        });
})(window);

(global => {
    const node = document.querySelector('.c-nav--lang');

    if (!node) {
        return;
    }

    node.addEventListener('click', (e) => {
        e.currentTarget.classList.toggle('c-nav--lang--is-open');
    });
})(window);

(global => {
    const node = document.getElementById('js-map--regions');

    if (!node) {
        return;
    }

    initRegionsMap(node);
})(window);

(global => {
    document.querySelectorAll('.js-toggle--nav').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.toggle('is-nav--open');
        });
    });

    document.querySelectorAll('.js-toggle--aside').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.remove('is-aside--open');
            document.body.classList.remove('is-aside--open-additional');
            document.body.classList.remove('is-aside--open-city');
        });
    });

    document.querySelectorAll('.js-toggle--aside-city').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.add('is-aside--open');
            document.body.classList.remove('is-aside--open-additional');
            document.body.classList.add('is-aside--open-city');
        });
    });

    document.querySelectorAll('.js-toggle--aside--additional').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.toggle('is-aside--open');
            document.body.classList.remove('is-aside--open-city');
            document.body.classList.add('is-aside--open-additional');
        });
    });

})(window);

// https://developers-dot-devsite-v2-prod.appspot.com/maps/documentation/javascript/examples/overlay-popup
function createPopupClass () {
    function Popup (position, city, pos = 'top') {
        this.position = position;

        var content = document.createElement('div');
        content.innerHTML = city || '';

        content.classList.add('popup-bubble');
        content.classList.add('popup-bubble--' + pos);

        // This zero-height div is positioned at the bottom of the bubble.
        var bubbleAnchor = document.createElement('div');
        bubbleAnchor.classList.add('popup-bubble-anchor');
        bubbleAnchor.appendChild(content);

        // This zero-height div is positioned at the bottom of the tip.
        this.containerDiv = document.createElement('div');
        this.containerDiv.classList.add('popup-container');
        this.containerDiv.appendChild(bubbleAnchor);

        // Optionally stop clicks, etc., from bubbling up to the map.
        window.google.maps.OverlayView.preventMapHitsAndGesturesFrom(this.containerDiv);
    }
    // ES5 magic to extend google.maps.OverlayView.
    Popup.prototype = Object.create(window.google.maps.OverlayView.prototype);

    /** Called when the popup is added to the map. */
    Popup.prototype.onAdd = function () {
        this.getPanes().floatPane.appendChild(this.containerDiv);
    };

    /** Called when the popup is removed from the map. */
    Popup.prototype.onRemove = function () {
        if (this.containerDiv.parentElement) {
            this.containerDiv.parentElement.removeChild(this.containerDiv);
        }
    };

    /** Called each frame when the popup needs to draw itself. */
    Popup.prototype.draw = function () {
        var divPosition = this.getProjection().fromLatLngToDivPixel(this.position);

        // Hide the popup when it is far out of view.
        var display =
        Math.abs(divPosition.x) < 4000 && Math.abs(divPosition.y) < 4000 ? 'block' : 'none';

        if (display === 'block') {
            this.containerDiv.style.left = divPosition.x + 'px';
            this.containerDiv.style.top = divPosition.y + 'px';
        }
        if (this.containerDiv.style.display !== display) {
            this.containerDiv.style.display = display;
        }
    };

    return Popup;
}

var info;

function setCitiesMarkers (map, positions) {
    const Popup = createPopupClass();
    const bounds = new window.google.maps.LatLngBounds();

    let popup;

    for (var i = 0; i < positions.length; i++) {
        const position = positions[i];
        const pos = new window.google.maps.LatLng(position.lat, position.lng);

        popup = new Popup(pos, position.title, position.pos);
        popup.setMap(map);

        bounds.extend(pos);
    }

    map.fitBounds(bounds);
}

function setMarkers (map, positions, focus) {
    var bounds = new window.google.maps.LatLngBounds();

    for (var i = 0; i < positions.length; i++) {
        const position = positions[i];
        const pos = new window.google.maps.LatLng(position.lat, position.lng);

        var marker = new window.google.maps.Marker({
            position: pos,
            map: map,
            icon: '/wp-content/themes/biuro/i/ico--map-pin.svg',
            title: position.title || ''
        });

        if (info) {
            info.close();
        }

        bounds.extend(pos);

        if (position.content) {
            marker['content'] = position.content;

            window.google.maps.event.addListener(marker, 'click', function () {
                info = new window.google.maps.InfoWindow({
                    content: this.content
                });

                info.open(map, this);
            });
        }

        if (focus) {
            if (window.innerWidth < 960) {
                window.scrollTo(0, 0);
            }
            new google.maps.event.trigger( marker, 'click' );
        }
    }

    map.fitBounds(bounds);

    if (window.innerWidth > 1020) {
        map.panBy(250, 0);
    } else if (window.innerWidth > 959) {
        map.panBy(180, 0);
    }
}

function setGoogleMap (node) {
    const mapStyles = [
        {
            featureType: 'all',
            elementType: 'all',
            stylers: [{ saturation: -92 }, { lightness: -8 }, { hue: '#004ed4' }]
        },
        {
            featureType: 'water',
            elementType: 'all',
            stylers: [{ saturation: -95 }, { lightness: -25 }, { hue: '#004ed4' }]
        }
    ];

    var map = new window.google.maps.Map(node, {});

    var biuroMap = new window.google.maps.StyledMapType(mapStyles, { name: 'Biuro' });

    map.mapTypes.set('biuro', biuroMap);

    map.setMapTypeId('biuro');

    window.google.maps.event.addListenerOnce(map, 'bounds_changed', function () {
        if (this.getZoom() > 15) {
            this.setZoom(14);
        }
    });

    return map;
}

function initCitiesMap (node, cities) {
    if (!window.google) {
        setTimeout(() => { initCitiesMap(node, cities); }, 250);
        return;
    }

    // console.error(cities);

    var map = setGoogleMap(node);

    // const cities = [
    //     { title: 'Skuodas', lat: 56.270161, lng: 21.530640 },
    //     { title: 'Mažeikiai', lat: 56.310871, lng: 22.348021 },
    //     { title: 'Akmenė', lat: 56.245010, lng: 22.750160 },
    //     { title: 'Venta', lat: 56.191240, lng: 22.687820 },
    //     { title: 'Papilė', lat: 56.152290, lng: 22.791190 },
    //     { title: 'Kuršėnai', lat: 56.002360, lng: 22.937360 },
    //     { title: 'Telšiai', lat: 55.983580, lng: 22.250810 },
    //     { title: 'Plungė', lat: 55.912470, lng: 21.846000 },
    //     { title: 'Varniai', lat: 55.742020, lng: 22.371730 },
    //     { title: 'Rietavas', lat: 55.723930, lng: 21.931480 },
    //     { title: 'Šilalė', lat: 55.491000, lng: 22.181270 }
    // ];

    setCitiesMarkers(map, cities);
}

function initRegionsMap (node) {
    if (!window.google) {
        setTimeout(() => { initRegionsMap(node); }, 250);
        return;
    }

    var map = setGoogleMap(node);

    const regions = [
        { title: 'Vilnius', lat: 54.687157, lng: 25.279652 },
        { title: 'Rīga', lat: 56.946285, lng: 24.105078 },
        { title: 'Tallinn', lat: 59.436962, lng: 24.753574 }
    ];

    setMarkers(map, regions);
}

function initDivisionsMap (node, data) {
    if (!window.google) {
        setTimeout(() => { initDivisionsMap(node, data); }, 250);
        return;
    }

    var map = setGoogleMap(node);

    let divisions = [];

    Object.keys(data).forEach((key) => {
        const division = data[key];
        if (key.substr(0, 4) === 'city') {
            divisions = divisions.concat(division);
        }
    });

    document.querySelectorAll('.js-division').forEach((node) => {
        node.addEventListener('click', () => {
            const ID = (node && node.dataset.id) ? node.dataset.id : '';

            if (data[ID]) {
                setMarkers(map, data[ID].filter((d) => { return d.lat && d.lng; }), true);
            } else {
                setMarkers(map, divisions.filter((d) => { return d.lat && d.lng; }));
            }
        });
    });

    setMarkers(map, divisions.filter((d) => { return d.lat && d.lng; }));
}

document.querySelectorAll('.js-form--input-file').forEach((node) => {
    node.addEventListener('change', () => {
        const parent = node.parentNode;
        const name = node.value.split(/\\|\//).pop();
        const text = parent.querySelector('.js-form--input-file-text');

        if (text && name) {
            text.innerHTML = name;
        }
    });
});

document.querySelectorAll('.js-toggle--services').forEach((node) => {
    node.addEventListener('click', () => {
        node.parentNode.classList.toggle('c-services--is-open');
    });
});

document.querySelectorAll('.js-toggle--sections').forEach((node) => {
    node.addEventListener('click', () => {
        const parent = node.parentNode;

        if (parent.classList.contains('c-sections--is-open')) {
            parent.classList.toggle('c-sections--is-open');
        } else {
            document.querySelectorAll('.c-sections--is-open').forEach((node) => {
                node.classList.remove('c-sections--is-open');
            });
            parent.classList.toggle('c-sections--is-open');
        }
    });
});

document.querySelectorAll('.js-expand-jobs-section').forEach((node) => {
    node.addEventListener('click', (e) => {
        e.preventDefault();
        node.parentNode.classList.remove('c-jobs-section--is-closed');
        node.remove();
    });
});

const initiatePositionForm = () => {
    const button = document.querySelector('[name="s"][value="1"]');

    if (button) {
        button.click();
        return;
    }

    const input = document.querySelector('[name="name"]');

    if (input) {
        input.focus();
    }
};

if (document.querySelector('.js-inititate-position-form')) {
    document.querySelector('.js-inititate-position-form').addEventListener('click', initiatePositionForm);
}

if (document.querySelector('.js-focus-form')) {
    document.querySelector('.js-focus-form').addEventListener('click', () => {
        const input = document.querySelector('.c-form input:first-of-type');

        if (input) {
            input.focus();
        }
    });
}

if (document.querySelector('.js-modal--close')) {
    document.querySelector('.js-modal--close').addEventListener('click', () => {
        const modal = document.querySelector('.c-modal');

        if (modal) {
            modal.remove();
        }

        const node = document.querySelector('.c-form [autofocus]');

        if (node) {
            node.focus();
        }
    });
}

function fallbackCopyTextToClipboard (text) {
    var textArea = document.createElement('textarea');
    textArea.value = text;
    document.body.appendChild(textArea);
    textArea.focus();
    textArea.select();

    try {
        var successful = document.execCommand('copy');
        var msg = successful ? 'successful' : 'unsuccessful';
        console.log('Fallback: Copying text command was ' + msg);
    } catch (err) {
        console.error('Fallback: Oops, unable to copy', err);
    }

    document.body.removeChild(textArea);
}

function showCopyTooltip () {
    const tooltip = document.querySelector('#copy-tooltip');

    if (tooltip) {
        tooltip.style.opacity = 1;

        setTimeout(() => {
            tooltip.style.opacity = 0;
        }, 3000);
    }
}

function copyTextToClipboard (text) {
    if (!navigator.clipboard) {
        fallbackCopyTextToClipboard(text);
        showCopyTooltip();
        return;
    }
    navigator.clipboard.writeText(text).then(function() {
        showCopyTooltip();
    }, function (err) {
        console.error('Async: Could not copy text: ', err);
    });
}

if (document.querySelector('.js-copy-to-clipboard')) {
    document.querySelector('.js-copy-to-clipboard').addEventListener('click', (e) => {
        e.preventDefault();
        copyTextToClipboard(window.location.origin + window.location.pathname + '?utm_source=copy_share_button_job_page ');
    });
}

(global => {
    const node = document.querySelector('.c-form [autofocus]');

    if (node) {
        node.focus();
    }

    if (location.hash) {
        const error = document.querySelector('.c-form--input-wrap--error input') || document.querySelector('.c-form--checkbox--error');

        if (error) {
            error.focus();
            return;
        }

        const input = document.querySelector('.c-form [name="name"]');

        if (input) {
            input.focus();
        }
    }
})(window);

(global => {
    document.querySelectorAll('.gtm-share-click').forEach((node) => {
        node.addEventListener('click', (e) => {
            window.dataLayer = window.dataLayer || [];
            window.dataLayer.push({
                event: 'shareClick',
                shareLabel: node.dataset.label || ''
            });
        });
    });
})(window);

// async function autocomplete() {
//     // await import(/* webpackChunkName: "autocomplete" */ './components/autocomplete');
//     const aaaa = require('./components/autocomplete').default;
// }

// if (document.getElementById('search-city') || document.getElementById('search-query') || document.getElementById('form-city')) {
//     autocomplete();
// }

// async function feedbacks() {
//     await import(/* webpackChunkName: "feedbacks" */ './components/feedbacks');
// };

// if (document.querySelectorAll('.c-feedbacks--inner').length) {
//     feedbacks();
// }

const submitContactsFrom = (form) => {
    if (form.querySelector('[type="submit"]')) {
        form.querySelector('[type="submit"]').classList.add('c-btn--disabled');
    }
};

document.querySelectorAll('[name="form-position"], [name="form-employees"], [name="form-employers"], [name="form-recommend"]').forEach((form) => {
    form.addEventListener('submit', () => { submitContactsFrom(form); });
});

if (document.querySelector('#submit-recommend')) {
    document.querySelector('#submit-recommend').addEventListener('click', (e) => {
        e.preventDefault();

        const button = document.querySelector('[name="form-recommend"] [type="submit"]');

        if (!button) {
            return;
        }

        e.currentTarget.classList.add('c-btn--disabled');

        button.click();
    });
}

if (document.querySelector('.js-submit-employees-form')) {
    document.querySelector('.js-submit-employees-form').addEventListener('click', (e) => {
        const button = document.querySelector('[name="form-employees"] [type="submit"]');

        if (!button) {
            return;
        }

        e.preventDefault();

        e.currentTarget.classList.add('c-btn--disabled');

        button.click();
    });
}

const collapseContent = (n) => {
    const h = n.scrollHeight;
    const t = n.style.transition;

    n.style.transition = '';

    requestAnimationFrame(() => {
        n.style.height = h + 'px';
        n.style.transition = t;

        requestAnimationFrame(() => {
            n.style.height = 0 + 'px';
        });
    });
};

const expandContent = (n) => {
    const h = n.scrollHeight;
    const done = (e) => {
        n.removeEventListener('transitionend', done);

        // n.style.height = null;
    };

    n.style.height = h + 'px';

    n.addEventListener('transitionend', done);
};

document.querySelectorAll('.js-accordion--header').forEach((header) => {
    header.addEventListener('click', () => {
        const node = header.nextElementSibling;

        if (!node || !node.classList.contains('c-accordion--content')) {
            return;
        }

        const isOpen = header.classList.contains('c-accordion--header--is-expanded');

        if (isOpen) {
            collapseContent(node);
        } else {
            expandContent(node);
        }

        header.classList.toggle('c-accordion--header--is-expanded', !isOpen);
    });
});

document.querySelectorAll('.c-accordion--content').forEach((content) => {
    content.classList.add('c-accordion--content--is-collapsed');
});

let isPageActive = true;

window.onfocus = function () {
    isPageActive = true;
};

window.onblur = function () {
    isPageActive = false;
};

const messenger = document.querySelector('.js-share-messenger');

if (messenger) {
    messenger.addEventListener('click', (e) => {
        e.preventDefault();

        const target = e.currentTarget;

        window.location.href = 'fb-messenger://share/?link=' + encodeURIComponent(window.location.origin + window.location.pathname + '?utm_source=messenger_share_button_job_page&app_id=' + target.dataset.id);

        setTimeout(() => {
            if (document.hidden || !isPageActive) {
                return;
            }

            window.location.href = target.href;
        }, 100);
    });
}

const whatsapp = document.querySelector('.js-share-whatsapp');

if (whatsapp) {
    whatsapp.addEventListener('click', (e) => {
        e.preventDefault();

        const target = e.currentTarget;

        window.location.href = 'whatsapp://send?text=' + target.dataset.text;

        setTimeout(() => {
            if (document.hidden || !isPageActive) {
                return;
            }

            window.open(target.href, '_blank');
        }, 100);
    });
}
